==> cms_content_sync-8.x-1.33.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/entity_handler/DefaultNodeHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler;

use Drupal\Core\Entity\EntityInterface;
use Drupal\cms_content_sync\PushIntent;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\SyncIntent;
use Drupal\cms_content_sync\Plugin\EntityHandlerBase;

/**
 * Class DefaultNodeHandler, providing proper handling for published/unpublished
 * content.
 *
 * @EntityHandler(
 *   id = "cms_content_sync_default_node_handler",
 *   label = @Translation("Default Node"),
 *   weight = 90
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler
 */
class DefaultNodeHandler extends EntityHandlerBase {

  const USER_PROPERTY = 'uid';
  const USER_REVISION_PROPERTY = 'revision_uid';

  /**
   * @inheritdoc
   */
  public static function supports($entity_type, $bundle) {
    return $entity_type == 'node';
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPushOptions() {
    return [
      PushIntent::PUSH_DISABLED,
      PushIntent::PUSH_AUTOMATICALLY,
      PushIntent::PUSH_AS_DEPENDENCY,
      PushIntent::PUSH_MANUALLY,
    ];
  }

  /**
   * @inheritdoc
   */
  public function push(PushIntent $intent, EntityInterface $entity = NULL) {
    if (!parent::push($intent, $entity)) {
      return FALSE;
    }

    if (!$entity) {
      $entity = $intent->getEntity();
    }

    /**
     * @var \Drupal\node\NodeInterface $entity
     */
    $intent->setField('created', intval($entity->getCreatedTime()));
    return TRUE;
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPreviewOptions() {
    return [
      'table' => 'Table',
      'preview_mode' => 'Preview mode',
    ];
  }

  /**
   * @inheritdoc
   */
  public function getHandlerSettings($current_values, $type = 'both') {
    $options = parent::getHandlerSettings($current_values, $type);

    // TODO Move to default handler for all entities that can be published.
    $options['ignore_unpublished'] = [
      '#type' => 'checkbox',
      '#title' => 'Ignore unpublished content',
      '#default_value' => isset($current_values['ignore_unpublished']) && $current_values['ignore_unpublished'] === 0 ? 0 : 1,
    ];

    $options['allow_explicit_unpublishing'] = [
      '#type' => 'checkbox',
      '#title' => 'Allow explicit unpublishing',
      '#default_value' => isset($current_values['allow_explicit_unpublishing']) && $current_values['allow_explicit_unpublishing'] === 0 ? 0 : 1,
    ];

    return $options;
  }

  /**
   * @inheritdoc
   */
  public function ignorePull(PullIntent $intent) {
    // Not published? Ignore this revision then.
    if (empty($intent->getField('status')) && $this->settings['handler_settings']['ignore_unpublished'] && !$this->settings['handler_settings']['allow_explicit_unpublishing']) {
      // Unless it's a delete, then it won't have a status and is independent
      // of published state, so we don't ignore the pull.
      if ($intent->getAction() != SyncIntent::ACTION_DELETE) {
        return TRUE;
      }
    }

    return parent::ignorePull($intent);
  }

  /**
   * @inheritdoc
   */
  public function ignorePush(PushIntent $intent) {
    /**
     * @var \Drupal\node\NodeInterface $entity
     */
    $entity = $intent->getEntity();
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $node = $node_storage->load($entity->id());

    if (!$entity->isPublished() && $this->settings['handler_settings']['ignore_unpublished']) {
      if (!$this->settings['handler_settings']['allow_explicit_unpublishing'] || $node->isPublished() || ($entity->getRevisionId() == $node->getRevisionId() && !$intent->getEntityStatus()->getLastPush())) {
        return TRUE;
      }
    }

    return parent::ignorePush($intent);
  }

}

==> cms_content_sync-8.x-1.35.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/entity_handler/DefaultNodeHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler;

use Drupal\Core\Entity\EntityInterface;
use Drupal\cms_content_sync\PushIntent;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\SyncIntent;
use Drupal\cms_content_sync\Plugin\EntityHandlerBase;

/**
 * Class DefaultNodeHandler, providing proper handling for published/unpublished
 * content.
 *
 * @EntityHandler(
 *   id = "cms_content_sync_default_node_handler",
 *   label = @Translation("Default Node"),
 *   weight = 90
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler
 */
class DefaultNodeHandler extends EntityHandlerBase {

  const USER_PROPERTY = 'uid';
  const USER_REVISION_PROPERTY = 'revision_uid';

  /**
   * @inheritdoc
   */
  public static function supports($entity_type, $bundle) {
    return $entity_type == 'node';
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPushOptions() {
    return [
      PushIntent::PUSH_DISABLED,
      PushIntent::PUSH_AUTOMATICALLY,
      PushIntent::PUSH_AS_DEPENDENCY,
      PushIntent::PUSH_MANUALLY,
    ];
  }

  /**
   * @inheritdoc
   */
  public function push(PushIntent $intent, EntityInterface $entity = NULL) {
    if (!parent::push($intent, $entity)) {
      return FALSE;
    }

    if (!$entity) {
      $entity = $intent->getEntity();
    }

    /**
     * @var \Drupal\node\NodeInterface $entity
     */
    $intent->setProperty('created', intval($entity->getCreatedTime()));
    return TRUE;
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPreviewOptions() {
    return [
      'table' => 'Table',
      'preview_mode' => 'Preview mode',
    ];
  }

  /**
   * @inheritdoc
   */
  public function getHandlerSettings($current_values, $type = 'both') {
    $options = parent::getHandlerSettings($current_values, $type);

    // TODO Move to default handler for all entities that can be published.
    $options['ignore_unpublished'] = [
      '#type' => 'checkbox',
      '#title' => 'Ignore unpublished content',
      '#default_value' => isset($current_values['ignore_unpublished']) && $current_values['ignore_unpublished'] === 0 ? 0 : 1,
    ];

    $options['allow_explicit_unpublishing'] = [
      '#type' => 'checkbox',
      '#title' => 'Allow explicit unpublishing',
      '#default_value' => isset($current_values['allow_explicit_unpublishing']) && $current_values['allow_explicit_unpublishing'] === 0 ? 0 : 1,
    ];

    return $options;
  }

  /**
   * @inheritdoc
   */
  public function ignorePull(PullIntent $intent) {
    // Not published? Ignore this revision then.
    if (empty($intent->getProperty('status')) && $this->settings['handler_settings']['ignore_unpublished'] && !$this->settings['handler_settings']['allow_explicit_unpublishing']) {
      // Unless it's a delete, then it won't have a status and is independent
      // of published state, so we don't ignore the pull.
      if ($intent->getAction() != SyncIntent::ACTION_DELETE) {
        return TRUE;
      }
    }

    return parent::ignorePull($intent);
  }

  /**
   * @inheritdoc
   */
  public function ignorePush(PushIntent $intent) {
    /**
     * @var \Drupal\node\NodeInterface $entity
     */
    $entity = $intent->getEntity();
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $node = $node_storage->load($entity->id());

    if (!$entity->isPublished() && $this->settings['handler_settings']['ignore_unpublished']) {
      if (!$this->settings['handler_settings']['allow_explicit_unpublishing'] || $node->isPublished() || ($entity->getRevisionId() == $node->getRevisionId() && !$intent->getEntityStatus()->getLastPush())) {
        return TRUE;
      }
    }

    return parent::ignorePush($intent);
  }

}
